# Messaging Drivers (Simplified for Debugging)

::: core.messager.drivers.DriverConfig

## Core Components

::: core.messager.drivers.DriverConfig

::: core.messager.drivers.create_driver

## Available Drivers

### MQTT

::: core.messager.drivers.MQTTDriver.MQTTDriver

### Kafka

::: core.messager.drivers.KafkaDriver.KafkaDriver

### RabbitMQ

::: core.messager.drivers.RabbitMQDriver.RabbitMQDriver

### Redis

::: core.messager.drivers.RedisDriver.RedisDriver 